==> artemis-commons-1.0.0-sources.jar: org/apache/activemq/artemis/utils/ReferenceCounterUtil.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.utils;

import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicInteger;

public class ReferenceCounterUtil implements ReferenceCounter
{
   private final Runnable runnable;

   /** If executor is null the runnable will be called within the same thread, otherwise the executor will be used */
   private final Executor executor;

   private final AtomicInteger uses = new AtomicInteger(0);


   public ReferenceCounterUtil(Runnable runnable)
   {
      this(runnable, null);
   }

   public ReferenceCounterUtil(Runnable runnable, Executor executor)
   {
      this.runnable = runnable;
      this.executor = executor;
   }

   @Override
   public int increment()
   {
      return uses.incrementAndGet();
   }

   @Override
   public int decrement()
   {
      int value = uses.decrementAndGet();
      if (value == 0)
      {
         if (executor != null)
         {
            executor.execute(runnable);
         }
         else
         {
            runnable.run();
         }
      }

      return value;
   }
}

==> artemis-commons-2.3.0-sources.jar: org/apache/activemq/artemis/utils/ReferenceCounterUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.utils;

import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicInteger;

public class ReferenceCounterUtil implements ReferenceCounter {

   private final Runnable runnable;

   /**
    * If executor is null the runnable will be called within the same thread, otherwise the executor will be used
    */
   private final Executor executor;

   private final AtomicInteger uses = new AtomicInteger(0);

   public ReferenceCounterUtil(Runnable runnable) {
      this(runnable, null);
   }

   public ReferenceCounterUtil(Runnable runnable, Executor executor) {
      this.runnable = runnable;
      this.executor = executor;
   }

   @Override
   public int increment() {
      return uses.incrementAndGet();
   }

   @Override
   public int decrement() {
      int value = uses.decrementAndGet();
      if (value == 0) {
         if (executor != null) {
            executor.execute(runnable);
         } else {
            runnable.run();
         }
      }

      return value;
   }
}
